==> 0.0.7.tar.gz: lib/logic/form_field_validators.dart <==
library flutter_firebase_basic_tools;

import 'package:flutter/material.dart';

enum FormFieldValidatorsType {
  email,
  password,
  firstname,
  lastname,
  custom,
}

class FormFieldValidators {
  const FormFieldValidators({
    @required this.value,
    @required this.type,
    this.customMessage,
    this.customPattern,
  });

  final String value;
  final FormFieldValidatorsType type;
  final String customMessage;
  final Pattern customPattern;

  String validate() {
    Pattern pattern;
    Pattern message;

    switch (type) {
      case FormFieldValidatorsType.email:
        {
          pattern =
              r'^(([^<>()[\]\\.,;:\s@\"]+(\.[^<>()[\]\\.,;:\s@\"]+)*)|(\".+\"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$';
          message = 'Email format is invalid';
        }
        break;

      case FormFieldValidatorsType.password:
        {}
        break;

      case FormFieldValidatorsType.firstname:
        {
          pattern = r"^[a-zA-Z]{2,25}$";
          message = "Enter a valid first name";
        }
        break;

      case FormFieldValidatorsType.lastname:
        {
          pattern = r"^[a-zA-Z]{2,25}$";
          message = "Enter a valid last name";
        }
        break;

      case FormFieldValidatorsType.custom:
        {
          if (customMessage != null && customPattern != null) {
            message = customMessage;
            pattern = customPattern;
          } else {
            assert(
              customMessage != null && customPattern != null,
              "Custom validator require a custom message and a custom pattern",
            );
          }
        }
        break;
    }

    if (type == FormFieldValidatorsType.password) {
      if (value.length > 7) {
        bool hasNumber = false;
        bool hasLetter = false;
        bool hasUppercase = false;
        bool hasLowercase = false;

        for (int i = 0; i < value.length; i++) {
          String subValue = value.substring(i);
          hasNumber = int.tryParse(subValue) != null;
          hasLetter = int.tryParse(subValue) == null;
          hasUppercase = subValue.toUpperCase() == subValue;
          hasLowercase = subValue.toLowerCase() == subValue;
        }

        if (hasNumber) {
          if (hasLetter) {
            if (hasUppercase) {
              if (hasLowercase) {
                return null;
              } else {
                return "Must contain lowercase";
              }
            } else {
              return "Must contain uppercase";
            }
          } else {
            return "Must contain a letter";
          }
        } else {
          return "Must contain a number";
        }
      } else {
        return "At least 8 characters";
      }
    } else {
      RegExp regex = new RegExp(pattern);
      if (!regex.hasMatch(value)) {
        return message;
      } else {
        return null;
      }
    }
  }
}

==> 0.0.9.tar.gz: lib/logic/form_field_validators.dart <==
library flutter_firebase_basic_tools;

import 'package:flutter/material.dart';

enum FormFieldValidatorsType {
  email,
  password,
  firstname,
  lastname,
  custom,
}

class FormFieldValidators {
  const FormFieldValidators({
    @required this.value,
    @required this.type,
    this.customMessage,
    this.customPattern,
  });

  final String value;
  final FormFieldValidatorsType type;
  final String customMessage;
  final Pattern customPattern;

  String validate() {
    Pattern pattern;
    Pattern message;

    switch (type) {
      case FormFieldValidatorsType.email:
        {
          pattern =
              r'^(([^<>()[\]\\.,;:\s@\"]+(\.[^<>()[\]\\.,;:\s@\"]+)*)|(\".+\"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$';
          message = 'Email format is invalid';
        }
        break;

      case FormFieldValidatorsType.password:
        {}
        break;

      case FormFieldValidatorsType.firstname:
        {
          pattern = r"^[a-zA-Z]{2,25}$";
          message = "Enter a valid first name";
        }
        break;

      case FormFieldValidatorsType.lastname:
        {
          pattern = r"^[a-zA-Z]{2,25}$";
          message = "Enter a valid last name";
        }
        break;

      case FormFieldValidatorsType.custom:
        {
          if (customMessage != null && customPattern != null) {
            message = customMessage;
            pattern = customPattern;
          } else {
            assert(
              customMessage != null && customPattern != null,
              "Custom validator require a custom message and a custom pattern",
            );
          }
        }
        break;
    }

    if (type == FormFieldValidatorsType.password) {
      if (value.length > 7) {
        bool hasNumber = false;
        bool hasLetter = false;
        bool hasUppercase = false;
        bool hasLowercase = false;

        for (int i = 0; i < value.length; i++) {
          String subValue = value.substring(i);

          if (int.tryParse(subValue) != null) {
            hasNumber = true;
          }

          if (int.tryParse(subValue) == null) {
            hasLetter = true;

            if (subValue.toUpperCase() == subValue) {
              hasUppercase = true;
            }

            if (subValue.toLowerCase() == subValue) {
              hasLowercase = true;
            }
          }
        }

        if (hasNumber) {
          if (hasLetter) {
            if (hasUppercase) {
              if (hasLowercase) {
                return null;
              } else {
                return "Must contain lowercase";
              }
            } else {
              return "Must contain uppercase";
            }
          } else {
            return "Must contain a letter";
          }
        } else {
          return "Must contain a number";
        }
      } else {
        return "At least 8 characters";
      }
    } else {
      RegExp regex = new RegExp(pattern);
      if (!regex.hasMatch(value)) {
        return message;
      } else {
        return null;
      }
    }
  }
}
